// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho...  1 julio 2013
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY
//
// HEDA HornoElectricoDomesticoAjustable
// El archivo dibuja un Horno con funcionalidad de Tostador y Parrilla.
// De escaso volumen, para uso Domestico.
//
// La macro default tiene cuatro parametros
// #macro HEDA_Horno( AnguloPerilla1, AnguloPerilla2,
//                FactorPuerta, FactorBandeja )
//      AnguloPerilla1          : Angulo en grados para rotar la perilla
//              superior a partir de la vertical.
//      AnguloPerilla2          : Angulo en grados para rotar la perilla
//              inferior a partir de la vertical.
//      FactorPuerta            : Fraccion propia para indicar la apertura
//              del horno.  0 cerrado a menos de 1 abierto.  No utilice 1,
//              de lo contrario la puerta se abre paralela al piso y lo
//              perfora (defecto).
//      FactorBandeja           : Fraccion para desplazar la rejilla y
//              bandeja hacia afuera.  La bandeja se desplaza mas que
//              la rejilla.  0 para aparato cerrado, 1 para un
//              desplazamiento de la bandeja igual a su propio ancho.
//
// Las dimensiones del horno tostador cerrado son:
//      Alto total              =   120.0*L
//      Frente                  =  -132.0*L..+140.0*L
//      Profundidad             =   165.0*L
// Se dibuja sobre el plano XZ hemisferio positivo
// y sobre el plano XY hemisferio negativo
// parcialmente centrado en el origen.
// El frente sobresale en direccion Z-, con gravedad Y-.
//
// La siguiente macro permite mayor flexibilidad:
// #macro HEDA_HornoElectricoDomesticoAjustable(
//    AnguloPerilla1, AnguloPerilla2, FactorPuerta, FactorBandeja,
//    FrenteBasico, AltoBasico, ProfundidadBasico,
//    GruesoPared, DiametroPerilla,
//    TexturaPrincipal, TexturaMetal, TexturaCeramica, MaterialIncandescente,
//    TexturaInferiorTapa, TexturaSuperiorTapa, MaterialVidrio,
//    TexturaIndicador, TexturaPatas )
//      AnguloPerilla1          : Angulo en grados para rotar la perilla
//              superior a partir de la vertical.
//      AnguloPerilla2          : Angulo en grados para rotar la perilla
//              inferior a partir de la vertical.
//      FactorPuerta            : Fraccion propia para indicar la apertura
//              del horno.  0 cerrado menos de 1 abierto.  No utilice 1,
//              de lo contrario la puerta se abre paralela al piso y lo
//              perfora (defecto).
//      FactorBandeja           : Fraccion para desplazar la rejilla y
//              bandeja hacia afuera.  La bandeja se desplaza mas que
//              la rejilla.  0 para aparato cerrado, 1 para un
//              desplazamiento de la bandeja igual a su propio ancho.
//      FrenteBasico            : Frente del horno.  Default es 264*L.
//      AltoBasico              : Alto del horno sin patas.  Default es 114*L.
//      ProfundidadBasico       : Referencia para la profundidad Z
//              del horno.  Default es 157*L.
//      GruesoPared             : Grueso control para volumen de paredes
//              metalicas con capas de aire aislante al resto
//              de la estructura.  Default es 6*L.
//      DiametroPerilla         : Diametro de las perillas de control.
//              Default es 28.5*L.
//      TexturaPrincipal        : Textura principal a aplicar al aparato.
//              Default es HEDA_TexturaPrincipal.
//      TexturaMetal            : Textura metalica del horno.
//              Default es HEDA_TexturaMetal.
//      TexturaCeramica         : Textura para la ceramica que sostiene
//              los bulbos incandescentes.  Default es HEDA_TexturaCeramica.
//      MaterialIncandescente   : Material a aplicar a los bulbos
//              incandescentes.  Default es HEDA_MaterialIncandescente.
//      TexturaInferiorTapa     : Textura para el decorado inferior de
//              la tapa.  Default es HEDA_TexturaInferiorTapa.
//      TexturaSuperiorTapa     : Textura para el decorado superior de
//              la tapa.  Default es HEDA_TexturaSuperiorTapa.
//      MaterialVidrio          : Material para el vidrio de la tapa.
//              Default es HEDA_MaterialVidrio.
//      TexturaIndicador        : Textura para el indicador rojo
//              superior derecho del horno.
//              Default es HEDA_TexturaIndicador.
//      TexturaPatas            : Textura para las patas.
//              Default es HEDA_TexturaPatas.
//
// Estas son variables predefinidas o generadas en el
// interior de las macros que no deberian modificarse directamente.
// Si quiere cambiarlas, recurra a los modificadores.
// #declare HEDA_DefaultTexturaPrincipal
//      Textura principal a aplicar al aparato.
// #declare HEDA_DefaultTexturaMetal
//      Textura metalica del horno.
// #declare HEDA_DefaultTexturaCeramica
//      Textura para la ceramica que sostiene los bulbos incandescentes.
// #declare HEDA_DefaultMaterialIncandescente
//      Material a aplicar a los bulbos incandescentes.
// #declare HEDA_DefaultTexturaInferiorTapa
//      Textura para el decorado inferior de la tapa.
// #declare HEDA_DefaultTexturaSuperiorTapa
//      Textura para el decorado superior de la tapa.
// #declare HEDA_DefaultMaterialVidrio
//      Material para el vidrio de la tapa.
// #declare HEDA_DefaultTexturaIndicador
//      Textura para el indicador rojo superior derecho del horno.
// #declare HEDA_DefaultTexturaPatas
//      Textura para las patas.
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)
// #declare HEDA_TexturaPrincipal               = texture  { ... }
//      Textura principal a aplicar al aparato.
// #declare HEDA_TexturaMetal                   = texture  { ... }
//      Textura metalica del horno.
// #declare HEDA_TexturaCeramica                = texture  { ... }
//      Textura para la ceramica que sostiene los bulbos incandescentes.
// #declare HEDA_MaterialIncandescente          = material { ... }
//      Material a aplicar a los bulbos incandescentes.
// #declare HEDA_TexturaInferiorTapa            = texture  { ... }
//      Textura para el decorado inferior de la tapa.
// #declare HEDA_TexturaSuperiorTapa            = texture  { ... }
//      Textura para el decorado superior de la tapa.
// #declare HEDA_MaterialVidrio                 = material { ... }
//      Material para el vidrio de la tapa.
// #declare HEDA_TexturaIndicador               = texture  { ... }
//      Textura para el indicador rojo superior derecho del horno.
// #declare HEDA_TexturaPatas                   = texture  { ... }
//      Textura para las patas.
// #declare HEDA_BanderaTexto                   = on;
//      Si se inactiva "off" no dibuja los textos, ni los puntos
//      negros de control de las perillas.
// #declare HEDA_ColorTexto                     = Black;
//      Para cambiar el color de texto y marcas de control en perillas.
// #declare HEDA_StringMarca                    = "POV-Ray"
//      Permite cambiar el logo text de la supuesta marca del aparato.
// #declare HEDA_POV3_1                         = off;
//      Valor on activa modo de compatibilidad con POVRay 3.1.
//      En algunas versiones se activara automaticamente.
//      En esta version no cumple ninguna funcion.
//
// Para colocarlo simplemente
// #include "HEDA.inc"
// object        { HEDA_Horno( 0, 0, 0, 0 ) }
//
// Otro ejemplo con modificador
// #include "HEDA.inc"
// #declare HEDA_TexturaPrincipal        = texture       {
//   average
//   texture_map        {
//     [ 0.5 HEDA_DefaultTexturaPrincipal ]
//     [ 0.5 Rust                         ]
//   }
// }
// object        {
//   HEDA_Horno( 0, 0, 0, 0 )
// }
//
// Un ejemplo con la macro detallada
// #include "HEDA.inc"
// object               {
//   HEDA_HornoElectricoDomesticoAjustable
//    ( 0, 0, 0, 0, 0.264, 0.114, 0.157, 0.006, 0.0285,
//      HEDA_TexturaPrincipal, HEDA_TexturaMetal,
//      HEDA_TexturaCeramica, HEDA_MaterialIncandescente,
//      HEDA_TexturaInferiorTapa, HEDA_TexturaSuperiorTapa,
//      HEDA_MaterialVidrio, HEDA_TexturaIndicador, HEDA_TexturaPatas )
// }
//

#include "colors.inc"

#declare OjoAbsoluto            = 256;
#declare VecesCentroAbsoluto    = 10;     
#declare L                      = 0.001;
camera {
        location  <   0,  0, -( VecesCentroAbsoluto+1 )*OjoAbsoluto >*L
        direction z
        sky       y
        angle     38.74
//        look_at  <   0,  0, -VecesCentroAbsoluto*OjoAbsoluto >*L
}         
light_source    {
         < 500  , 000   , -3000 >*L
         White
}
light_source    {
         <-500  , 500   , -3000 >*L
         White
}
background      {
         Gray50
}    

#include "heda.inc"
#include "glass.inc"
#include "textures.inc"
                        
#local FactorAcercamiento       = 4.5;                                                

object                  {
  HEDA_Horno(0,0,0.0,0.0)
  translate     -0.060*y-0.005*x             
  translate       -( VecesCentroAbsoluto+1 )
         *( FactorAcercamiento-1 )/( FactorAcercamiento )*OjoAbsoluto*L*z       
  
}

